@@ -5,7 +5,6 @@ OC.L10N.register(
     "Provided email-address is not valid" : "البريد المدخل غير صحيح",
     "%s has published the calendar »%s«" : "%s نشر التقويم »%s«",
     "Unexpected error sending email. Please contact your administrator." : "حدث خطأ اثناء إرسال البريد، تحقق من اعدادات البريد او تواصل مع مسؤول النظام.",
-    "Successfully sent email to " : "تم ارسال البريد بنجاح",
     "Hello," : "مرحبا %s،",
     "We wanted to inform you that %s has published the calendar »%s«." : "المستخدم %s قام بنشر تقويم »%s«.",
     "Open »%s«" : "فتح »%s«",
@@ -76,13 +75,14 @@ OC.L10N.register(
     "Creating subscription …" : "جاري انشاء اشتراك  …",
     "An error occurred, unable to create the calendar." : "حدث خطأ، لا يمكن انشاء التقويم.",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "يرجى ادخال رابط صحيح (يبدأ بـ https://, http://, webcals://, webcal://)",
+    "Untitled event" : "فعالية بدون اسم",
     "Could not update calendar order." : "لا يمكن تحديث ترتيب التقويم.",
     "Import calendars" : "استيراد التقويم",
     "Please select a calendar to import into …" : "يرجى اختيار تقويم للاستيراد اليه  …",
     "Filename" : "اسم الملف",
     "Calendar to import into" : "تقويم للاستيراد اليه",
     "Cancel" : "إلغاء",
-    "_Import calendar_::_Import calendars_" : ["استيراد التقويم","استيراد التقويم","استيراد التقويم","استيراد التقويم","استيراد التقويم","استيراد التقويم"],
+    "_Import calendar_::_Import calendars_" : ["استيراد التقويم","استيراد التقويم","استيراد التقويم","استيراد التقويم","استيراد التقويم"],
     "Automatic" : "تلقائي",
     "Automatic ({detected})" : "تلقائي ({detected})",
     "New setting was not saved successfully." : "لم يتم حفظ الاعدادات الجديدة.",
@@ -123,32 +123,23 @@ OC.L10N.register(
     "on" : "في",
     "at" : "في",
     "+ Add reminder" : "+ اضافة تذكير",
-    "_second_::_seconds_" : ["ثانية","ثانية","ثانية","ثواني","ثواني","ثواني"],
+    "_second_::_seconds_" : ["ثانية","ثانية","ثواني","ثواني","ثواني"],
     "No reminders yet" : "لا يوجد تذكير بعد",
     "Availability of attendees, resources and rooms" : "متوفرين من الحضور والموارد والغرف",
+    "Free" : "متوفر",
     "Busy (tentative)" : "مشغول (حاليا)",
     "Busy" : "مشغول",
     "Out of office" : "خارج المكتب",
     "Unknown" : "غير معروف",
-    "{name} accepted your invitation." : "{name} قبل دعوتك.",
-    "{name} accepted {organizerName}'s invitation." : "{name} قبل الدعوة من {organizerName}.",
-    "{name} declined your invitation." : "{name} رفض دعوتك.",
-    "{name} declined {organizerName}'s invitation." : "{name} رفض الدعوة من {organizerName}.",
-    "{name} has delegated their invitation." : "{name} اعاد توجيه الدعوة.",
-    "{name} marked their participation as tentative." : "{name} وضعوا علامة مشاركتهم على أنها مؤقتة.",
-    "{name} did not respond to your invitation yet." : "{name} لم يرد على دعوتك بعد.",
-    "{name} did not respond to {organizerName}'s invitation yet." : "{name} لم يرد على دعوة {organizerName} بعد.",
     "Create Talk room for this event" : "انشاء غرفة تحدث لهذه الفعالية.",
     "Show busy times" : "اظهار الاوقات الممتلئة",
     "Successfully appended link to talk room to description." : "تم اضافة الرابط في وصف غرفة التحدث بنجاح.",
     "Error creating Talk room" : "خطأ في انشاء غرفة تحدث",
-    "Send e-mail" : "ارسال بريد",
     "Chairperson" : "الرئيس",
     "Required participant" : "مشارك مطلوب",
     "Optional participant" : "مشارك اختياري",
     "Non-participant" : "غير مشارك",
     "Remove attendee" : "طرد الحاضر",
-    "Search for e-mails, users, contacts, resources or rooms" : "البحث باستخدام البريد، الاعضاء، جهات الاتصال، الموارد والغرف",
     "No match found" : "لا يوجد تطابق",
     "No attendees yet" : "لا يوجد حضور بعد",
     "(organizer)" : "(منظم)",
@@ -156,7 +147,6 @@ OC.L10N.register(
     "Remove color" : "حذف اللون",
     "Event title" : "عنوان الفعالية",
     "All day" : "اليوم بأكمله",
-    "Can not modify all-day setting for events that are part of a recurrence-set." : "لا يمكن تعيين اعدادات اليوم باكمله للفعالية التي تعيينها مكرر.",
     "from {startDate}" : "منذ تاريخ {startDate}",
     "from {startDate} at {startTime}" : "منذ تاريخ {startDate} في {startTime}",
     "to {endDate}" : "إلى تاريخ {endDate}",
@@ -166,7 +156,6 @@ OC.L10N.register(
     "never" : "بتاتاً",
     "on date" : "في تاريخ",
     "after" : "بعد",
-    "This event is the recurrence-exception of a recurrence-set. You can not add a recurrence-rule to it." : "هذه الفعالية تكرار استثنائي من تعيين التكرار. لا يمكن اضافة قانون تكرار لها.",
     "first" : "اول",
     "third" : "ثالث",
     "fourth" : "رابع",
@@ -178,7 +167,7 @@ OC.L10N.register(
     "Repeat every" : "تكرار كل",
     "By day of the month" : "يوم من الشهر",
     "On the" : "في الـ",
-    "_year_::_years_" : ["سنه","سنه","سنه","سنوات","سنوات","سنوات"],
+    "_year_::_years_" : ["سنه","سنه","سنوات","سنوات","سنوات"],
     "Monday" : "الإثنين",
     "weekday" : "ايام الاسبوع",
     "weekend day" : "يوم نهاية الاسبوع",
@@ -255,16 +244,8 @@ OC.L10N.register(
     "in {monthNames}" : "في {monthNames}",
     "in {monthNames} on the {ordinalNumber} {byDaySet}" : "في {monthNames} في الـ {ordinalNumber} {byDaySet}",
     "until {untilDate}" : "حتى {untilDate}",
-    "Untitled event" : "فعالية بدون اسم",
     "Untitled task" : "مهمة بدون اسم",
     "Please ask your administrator to enable the Tasks App." : "تواصل مع مسؤول النظام لاستخدام تطبيق المهام.",
-    "prev" : "السابق",
-    "next" : "التالي",
-    "prev year" : "العام السابق",
-    "next year" : "العام القادم",
-    "today" : "اليوم",
-    "list" : "قائمة",
-    "all-day" : "طوال اليوم",
     "%n more" : "%n المزيد",
     "No events to display" : "لا يوجد فعاليات",
     "No events" : "لا يوجد فعاليات",
@@ -287,7 +268,6 @@ OC.L10N.register(
     "Confirmation about the overall status of the event." : "التأكيد بخصوص الحالة العامة للفعالية.",
     "Show as" : "أظهر كـ",
     "Take this event into account when calculating free-busy information." : "ضع هذه الفعالية في الاعتبار عندما تكون معلومات الحالة متوفر/ مشغول.",
-    "Free" : "متوفر",
     "Categories" : "التصنيفات",
     "Categories help you to structure and organize your events." : "التصنيفات تساعدك للهيكله وتنظيم الفعالية.",
     "Search or add categories" : "ابحث او اضف تصنيف",
@@ -315,14 +295,10 @@ OC.L10N.register(
     "Review" : "مراجعة",
     "Office" : "مكتب",
     "Contributor week" : "اسبوع المساهم",
-    "Party" : "حفله",
-    "Celebration" : "احتفال",
     "Mail" : "البريد",
     "Soccer" : "كرة قدم امريكية",
     "Football" : "كرة قدم",
     "Gaming" : "العاب",
-    "Play" : "تشغيل",
-    "Game" : "لعبة",
     "Drive" : "سياقه",
     "Bicycle" : "ركوب دراجة",
     "Cycle" : "دراجة هوائية",
@@ -376,6 +352,8 @@ OC.L10N.register(
     "Lecture" : "محاضرة",
     "Seminar" : "ندوة",
     "Photograph" : "تصوير",
+    "Party" : "حفله",
+    "Celebration" : "احتفال",
     "Celebrate" : "احتفال",
     "Shopping" : "تسوق",
     "Skate" : "تزلج",
