@@ -29,10 +29,8 @@ OC.L10N.register(
     "Close" : "বন্ধ",
     "Daily" : "দৈনিক",
     "Weekly" : "সাপ্তাহিক",
-    "today" : "আজ",
     "Location" : "অবস্থান",
     "Description" : "বিবরণ",
-    "Mail" : "মেইল",
-    "Play" : "বাজাও"
+    "Mail" : "মেইল"
 },
 "nplurals=2; plural=(n != 1);");
