@@ -5,7 +5,6 @@ OC.L10N.register(
     "Provided email-address is not valid" : "Direizh eo ar chomlec'h postel",
     "%s has published the calendar »%s«" : "%s en deus embannet un deiziataer »%s«",
     "Unexpected error sending email. Please contact your administrator." : "C'hoarvezet ez eus ur fazi dic'hortoz en ur gas ar postel. Kit e darempred gant ho merour.",
-    "Successfully sent email to " : "Kaset eo bet ar postel ervat da",
     "Hello," : "Demat deoc'h,",
     "We wanted to inform you that %s has published the calendar »%s«." : "Kemenn a reomp deoc'h ez eus bet %s embannet un deiziataer » gant %s«",
     "Open »%s«" : "Digeriñ  »%s«",
@@ -92,6 +91,7 @@ OC.L10N.register(
     "Actions" : "Oberoù",
     "Notification" : "Kemenadenn",
     "Email" : "Postel",
+    "Free" : "Digoust",
     "Busy" : "O labourat",
     "Unknown" : "Dianv",
     "never" : "james",
@@ -118,13 +118,6 @@ OC.L10N.register(
     "_Every %n month_::_Every %n months_" : ["Bep miz","Bep %n viz","Bep %n miz","Bep %n miz","Bep %n miz"],
     "_Every %n year_::_Every %n years_" : ["Bep bloaz","Bep %n vloaz","Bep %n bloaz","Bep %n bloaz","Bep %n bloaz"],
     "_on {weekday}_::_on {weekdays}_" : ["d'al {weekday}","d'ar {weekday}","d'ar {weekday}","d'ar {weekday}","d'ar {weekday}"],
-    "prev" : "kent",
-    "next" : "war-lerc'h",
-    "prev year" : "bloaz kent",
-    "next year" : "bloaz war-lerc'h",
-    "today" : "hiziv",
-    "list" : "roll",
-    "all-day" : "a-hed an deiz",
     "%n more" : "%n ouzhpenn",
     "No events to display" : "Darvoud ebet da ziskouez",
     "No events" : "Darvoud ebet",
@@ -144,7 +137,6 @@ OC.L10N.register(
     "Confirmation about the overall status of the event." : "Kadarnaat statud hollek an darvoud.",
     "Show as" : "Diskouez evel",
     "Take this event into account when calculating free-busy information." : "Kemer an darvoud-mañ e kont pa vez jedet titouroù pres-dibres",
-    "Free" : "Digoust",
     "Categories" : "Rummadoù",
     "Categories help you to structure and organize your events." : "Ar rummadoù a harp ac'hanoc'h da aozañ ha da frammañ ho tarvoudoù",
     "Search or add categories" : "Klask hag ouzhpennañ rummadoù",
@@ -172,14 +164,10 @@ OC.L10N.register(
     "Review" : "Adwelet",
     "Office" : "Burev",
     "Contributor week" : "Sizhun ar berzhidi",
-    "Party" : "Fest",
-    "Celebration" : "Lid",
     "Mail" : "Postel",
     "Soccer" : "Mell-droad",
     "Football" : "Mell-droad",
     "Gaming" : "C'hoari",
-    "Play" : "C'hoari",
-    "Game" : "C'hoari",
     "Drive" : "Bleinañ",
     "Bicycle" : "Marc'h-houarn",
     "Cycle" : "Belo",
@@ -233,6 +221,8 @@ OC.L10N.register(
     "Lecture" : "Lenn",
     "Seminar" : "Seminar",
     "Photograph" : "Luc'hskeudenn",
+    "Party" : "Fest",
+    "Celebration" : "Lid",
     "Celebrate" : "Lid",
     "Shopping" : "Staliaoua",
     "Skate" : "Plankenn-ruilh",
