@@ -13,8 +13,10 @@ OC.L10N.register(
     "Week" : "Week",
     "Month" : "Month",
     "List" : "List",
+    "Edit color" : "Edit colour",
     "Download" : "Download",
     "Delete" : "Delete",
+    "An error occurred, unable to change the calendar's color." : "An error occurred, unable to change the calendar's colour.",
     "Share link" : "Share link",
     "Share with users or groups" : "Share with users or groups",
     "can edit" : "can edit",
@@ -48,8 +50,6 @@ OC.L10N.register(
     "Week {number} of {year}" : "Week {number} of {year}",
     "Daily" : "Daily",
     "Weekly" : "Weekly",
-    "next year" : "next year",
-    "today" : "today",
     "When shared show full event" : "When shared show full event",
     "When shared show only busy" : "When shared show only busy",
     "When shared hide this event" : "When shared hide this event",
@@ -59,11 +59,11 @@ OC.L10N.register(
     "Confirmed" : "Confirmed",
     "Tentative" : "Tentative",
     "Categories" : "Categories",
+    "Custom color" : "Custom colour",
     "Presentation" : "Presentation",
     "Review" : "Review",
     "Office" : "Office",
     "Mail" : "Mail",
-    "Play" : "Play",
     "Global" : "Global"
 },
 "nplurals=2; plural=(n != 1);");
