@@ -5,7 +5,6 @@ OC.L10N.register(
     "Provided email-address is not valid" : "آدرس ایمیل ارائه شده معتبر نیست",
     "%s has published the calendar »%s«" : "%sتقویم %s را منتشر کرده است.",
     "Unexpected error sending email. Please contact your administrator." : "خطای غیر منتظره در ارسال ایمیل. لطفا با مدیر خود تماس بگیرید.",
-    "Successfully sent email to " : "ایمیل با موفقیت ارسال شد",
     "Hello," : "سلام،",
     "We wanted to inform you that %s has published the calendar »%s«." : "مایل هستیم به شما اطلاع دهیم که %s تقویم شماره %s را منتشر کرده است.",
     "Open »%s«" : "باز کن »%s«",
@@ -77,6 +76,7 @@ OC.L10N.register(
     "Creating subscription …" : "ایجاد اشتراک…",
     "An error occurred, unable to create the calendar." : "خطایی روی داد ، قادر به ایجاد تقویم نیست.",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "لطفاً یک پیوند معتبر وارد کنید (با شروع http: // ، https: // ، webcal: // ، یا صفحات وب: //)",
+    "Untitled event" : "رویداد بدون عنوان",
     "Import calendars" : "وارد کردن تقویم ها",
     "Please select a calendar to import into …" : "لطفاً یک تقویم را برای وارد کردن به… انتخاب کنید",
     "Filename" : "نام فایل",
@@ -118,35 +118,25 @@ OC.L10N.register(
     "_week_::_weeks_" : ["هفته","هفته ها"],
     "No reminders yet" : "هنوز هیچ یادآوری نیست",
     "Availability of attendees, resources and rooms" : "در دسترس بودن شرکت کنندگان ، منابع و اتاق ها",
+    "Free" : "رایگان",
     "Busy (tentative)" : "مشغول (آزمایشی)",
     "Busy" : "مشغول",
     "Out of office" : "بیرون از دفتر",
     "Unknown" : "نامشخص",
-    "{name} accepted your invitation." : "{name} دعوت شما را پذیرفت.",
-    "{name} accepted {organizerName}'s invitation." : "دعوت نامه {name} قبول {organizerName}.",
-    "{name} declined your invitation." : "{name} دعوت شما را رد کرد.",
-    "{name} declined {organizerName}'s invitation." : "دعوت نامه {name} رد شده  {organizerName}.\n\n ",
-    "{name} has delegated their invitation." : "{name}  دعوت خود را به آنها اعطا کرده است.",
-    "{name} marked their participation as tentative." : "{name} مشارکت آنها را به عنوان آزمایشی مشخص کرد.",
-    "{name} did not respond to your invitation yet." : "{name} هنوز به دعوت شما پاسخ نداده",
-    "{name} did not respond to {organizerName}'s invitation yet." : "{name} پاسخی نداده به  {organizerName}'sدعوت هنوز.",
     "Create Talk room for this event" : "اتاق گفتگو را برای این رویداد ایجاد کنید",
     "Show busy times" : " نمایش  زمان‌های  شلوغ",
     "Successfully appended link to talk room to description." : "پیوند موفقیت آمیز پیوند به اتاق گفتگو به توضیحات.",
     "Error creating Talk room" : "خطا در ایجاد اتاق گفتگو",
-    "Send e-mail" : "ارسال ایمیل",
     "Chairperson" : "رئیس",
     "Required participant" : "شرکت کننده مورد نیاز",
     "Optional participant" : "شرکت کننده اختیاری",
     "Non-participant" : "غیر شرکت کننده",
     "Remove attendee" : "شرکت کننده را حذف کنید",
-    "Search for e-mails, users, contacts, resources or rooms" : "جستجوی ایمیل ، کاربران ، مخاطبین ، منابع یا اتاق ها",
     "No match found" : "هیچ تطبیقی یافت نشد",
     "No attendees yet" : "هنوز هیچ حضوری وجود ندارد",
     "(organizer)" : "(تنظیم کننده)",
     "Event title" : "عنوان رویداد",
     "All day" : "تمام روز",
-    "Can not modify all-day setting for events that are part of a recurrence-set." : "نمی توانید تنظیمات همه روزه را برای رویدادهایی که بخشی از مجموعه بازگشتی هستند تغییر دهید.",
     "from {startDate}" : "از {startDate}",
     "from {startDate} at {startTime}" : "از {startDate} در {startTime}",
     "to {endDate}" : "به {endDate}",
@@ -157,7 +147,6 @@ OC.L10N.register(
     "on date" : "در تاریخ",
     "after" : "بعد از",
     "_time_::_times_" : ["بار","بارها"],
-    "This event is the recurrence-exception of a recurrence-set. You can not add a recurrence-rule to it." : " این  رویداد  ,  استثنا  یک  مجموعه  بازگشتی  است  .  شما  نمی‌توانید  یک قاعده بازگشتی به آن اضافه کنید",
     "first" : "اولین",
     "third" : "سوم",
     "fourth" : "چهارم",
@@ -249,9 +238,6 @@ OC.L10N.register(
     "in {monthNames} on the {ordinalNumber} {byDaySet}" : "در {monthNames} در {ordinalNumber} {byDaySet}",
     "until {untilDate}" : "تا زمان {untilDate}",
     "_%n time_::_%n times_" : ["%n بار","%n بارها"],
-    "Untitled event" : "رویداد بدون عنوان",
-    "next year" : "سال آینده",
-    "today" : "امروز",
     "_+%n more_::_+%n more_" : ["+%n بیشتر","+%n بیشتر"],
     "When shared show" : "هنگام نمایش مشترک",
     "When shared show full event" : "هنگام اشتراک گذاری ، رویداد کامل را نشان می دهد",
@@ -268,7 +254,6 @@ OC.L10N.register(
     "Confirmation about the overall status of the event." : "تأیید درباره وضعیت کلی این رویداد.",
     "Show as" : "نمایش به عنوان",
     "Take this event into account when calculating free-busy information." : "هنگام محاسبه اطلاعات شلوغ رایگان ، این رویداد را در نظر بگیرید.",
-    "Free" : "رایگان",
     "Categories" : "دسته بندی ها",
     "Categories help you to structure and organize your events." : "دسته بندی ها به شما کمک می کنند تا وقایع خود را تنظیم و سازماندهی کنید.",
     "Search or add categories" : "دسته ها را جستجو یا اضافه کنید",
@@ -296,14 +281,10 @@ OC.L10N.register(
     "Review" : "مرور",
     "Office" : "دفتر",
     "Contributor week" : "هفته مشارکت کننده",
-    "Party" : "مهمانی - جشن",
-    "Celebration" : "جشن",
     "Mail" : "ایمیل",
     "Soccer" : "فوتبال",
     "Football" : "فوتبال",
     "Gaming" : "بازی",
-    "Play" : "پخش کردن",
-    "Game" : "بازی",
     "Drive" : "راندن",
     "Bicycle" : "دوچرخه",
     "Cycle" : "چرخه",
@@ -352,6 +333,8 @@ OC.L10N.register(
     "Lecture" : "سخنرانی",
     "Seminar" : "سمینار",
     "Photograph" : "عکس",
+    "Party" : "مهمانی - جشن",
+    "Celebration" : "جشن",
     "Celebrate" : "جشن گرفتن",
     "Shopping" : "خريد كردن",
     "Skate" : "اسکیت",
