@@ -25,10 +25,8 @@ OC.L10N.register(
     "Close" : "បិទ",
     "Daily" : "រាល់ថ្ងៃ",
     "Weekly" : "រាល់​សប្ដាហ៍",
-    "today" : "ថ្ងៃនេះ",
     "Location" : "ទីតាំង",
     "Description" : "ការ​អធិប្បាយ",
-    "Mail" : "សំបុត្រ",
-    "Play" : "លេង"
+    "Mail" : "សំបុត្រ"
 },
 "nplurals=1; plural=0;");
