@@ -1,9 +1,12 @@
 OC.L10N.register(
     "calendar",
     {
+    "Hello," : "Adieusiatz, ",
     "Open »%s«" : "Dobrir « %s »",
     "Cheers!" : "A lèu !",
+    "Upcoming events" : "Eveniments venents",
     "Calendar" : "Calendièr",
+    "A Calendar app for Nextcloud" : "Una aplicacion de calendièr per Nextcloud",
     "Previous day" : "Jorn passat",
     "Previous week" : "Setmana passada",
     "Previous month" : "Mes passat",
@@ -33,12 +36,14 @@ OC.L10N.register(
     "can edit" : "pòt modificar",
     "+ New calendar" : "+ Calendièr novèl",
     "New calendar" : "Calendièr novèl",
+    "Untitled event" : "Eveniment sens nom",
     "Import calendars" : "Importar de calendièrs",
     "Filename" : "Nom de fichièr",
     "Cancel" : "Anullar",
     "_Import calendar_::_Import calendars_" : ["Importar un calendièr","Importar de calendièrs"],
     "Automatic" : "Automatic",
     "or" : "o",
+    "Navigation" : "Navegacion",
     "Views" : "Vistas",
     "Day view" : "Mostrar un jorn",
     "Week view" : "Monstrar una setmana",
@@ -47,6 +52,8 @@ OC.L10N.register(
     "Show weekends" : "Monstrar las dimenjadas",
     "Notification" : "Notificacion",
     "Email" : "Adreça corrièl",
+    "Audio notification" : "Notificacion àudio",
+    "Other notification" : "Autras notificacions",
     "Edit time" : "Modificar l’ora",
     "Remove reminder" : "Suprimir lo rapèl",
     "on" : "lo",
@@ -70,12 +77,22 @@ OC.L10N.register(
     "fifth" : "cinquen",
     "last" : "darrièr",
     "Repeat" : "Repetir",
+    "_month_::_months_" : ["mes","mese"],
+    "_year_::_years_" : ["annada","annadas"],
     "Monday" : "diluns",
     "More" : "Mai",
     "Save" : "Salvar",
     "Update" : "Metre a jorn",
+    "Please select a timezone:" : "Causissètz una zòna orària :",
     "Pick a time" : "Causir una ora",
     "Pick a date" : "Causir una data",
+    "from {formattedDate}" : "a partir de {formattedDate}",
+    "to {formattedDate}" : "cap a {formattedDate}",
+    "Personal" : "Personal",
+    "[Today]" : "[Uèi]",
+    "[Tomorrow]" : "[Deman]",
+    "[Yesterday]" : "[Ièr]",
+    "[Last] dddd" : "dddd [passat]",
     "Details" : "Detalhs",
     "Attendees" : "Convidats",
     "Reminders" : "Rapèls",
@@ -87,6 +104,8 @@ OC.L10N.register(
     "Education" : "Educacion",
     "Holiday" : "Vacanças",
     "Meeting" : "Reünion",
+    "Travel" : "Viatge",
+    "Vacation" : "Vacanças",
     "Daily" : "Cada jorn",
     "Weekly" : "Cada setmana",
     "Monthly" : "Cada mes",
@@ -96,9 +115,7 @@ OC.L10N.register(
     "_Every %n month_::_Every %n months_" : ["Cada %n mes","Cada %n meses"],
     "_Every %n year_::_Every %n years_" : ["Cada %n an","Cada %n ans"],
     "_%n time_::_%n times_" : ["%n còp","%n còps"],
-    "Untitled event" : "Eveniment sens nom",
     "Untitled task" : "Prètzfach sens nom",
-    "today" : "uèi",
     "Location" : "Emplaçament",
     "Add a location" : "Apondre un lòc",
     "Description" : "Descripcion",
@@ -112,12 +129,14 @@ OC.L10N.register(
     "Presentation" : "Presentacion",
     "Movie" : "Film",
     "Cinema" : "Cinèma",
-    "Party" : "Fèsta",
     "Mail" : "Mail",
     "Gaming" : "Vidèo-jòc",
-    "Play" : "Aviar",
-    "Game" : "Jòc",
+    "Bicycle" : "Bicicleta",
+    "Fishing" : "Pesca",
+    "Hiking" : "Escalada",
+    "Art" : "Arts",
     "Museum" : "Musèu",
+    "Studying" : "Estudis",
     "Doctor" : "Mètge",
     "Health" : "Santat",
     "Dentist" : "Dentista",
@@ -127,6 +146,7 @@ OC.L10N.register(
     "Conference" : "Conferéncia",
     "Pizza" : "Pizza",
     "Travelling" : "Viatge",
+    "Party" : "Fèsta",
     "Shopping" : "Crompas",
     "Global" : "Global"
 },
