@@ -4,7 +4,6 @@ OC.L10N.register(
     "Provided email-address is not valid" : "Adresa de email furnizată este invalidă",
     "%s has published the calendar »%s«" : "%sa publicat calendarul »%s«",
     "Unexpected error sending email. Please contact your administrator." : "Eroare neașteptată la trimiterea emailului. Vă rog contactați-vă administratorul.",
-    "Successfully sent email to " : "Email trimis cu succes la ",
     "Hello," : "Salut,",
     "We wanted to inform you that %s has published the calendar »%s«." : "Vă informăm că %sa publicat calendarul »%s«.",
     "Open »%s«" : "Accesează »%s«",
@@ -66,8 +65,6 @@ OC.L10N.register(
     "Week {number} of {year}" : "Săptămâna {number} din {year}",
     "Daily" : "Zilnic",
     "Weekly" : "Săptămânal",
-    "next year" : "anul viitor",
-    "today" : "astăzi",
     "When shared show full event" : "Arată tot evenimentul la partajare",
     "When shared show only busy" : "Arată doar ocupat la partajare",
     "When shared hide this event" : "Ascunde evenimentul la partajare",
@@ -77,7 +74,6 @@ OC.L10N.register(
     "Confirmed" : "Confirmat",
     "Tentative" : "Tentativă",
     "Mail" : "Mail",
-    "Play" : "Redă",
     "Global" : "Global"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
