@@ -5,7 +5,6 @@ OC.L10N.register(
     "Provided email-address is not valid" : "Надано некоректну адресу електронної пошти ",
     "%s has published the calendar »%s«" : "%s опублікував календар »%s«",
     "Unexpected error sending email. Please contact your administrator." : "Виникла несподівана помилка під час надсилання електронного повідомлення. Будь-ласка повідомте Вашого адміністратора.",
-    "Successfully sent email to " : "Успішно надіслано електроннний лист",
     "Hello," : "Вітаємо,",
     "We wanted to inform you that %s has published the calendar »%s«." : "We wanted to inform you that %s has published the calendar »%s.",
     "Open »%s«" : "Відкрити 1%s",
@@ -77,6 +76,7 @@ OC.L10N.register(
     "Creating subscription …" : "Створюю підписку ...",
     "An error occurred, unable to create the calendar." : "Сталася помилка, неможливо створити календар.",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Будь-ласка, введіть корректне посилання (повинно починатися на http://, https://, webcal:// або webcals://)",
+    "Untitled event" : "Подія без назви",
     "Import calendars" : "Імпортувати календарі",
     "Please select a calendar to import into …" : "Будь-ласка, оберіть у який календар виконати імпорт ...",
     "Filename" : "Ім'я файлу",
@@ -135,36 +135,26 @@ OC.L10N.register(
     "_week_::_weeks_" : ["тиждень","тижнів","тижнів","тижні"],
     "No reminders yet" : "Жодного нагадування поки що",
     "Availability of attendees, resources and rooms" : "Доступність учасників, ресурсів і приміщень",
+    "Free" : "Вільно",
     "Busy (tentative)" : "Зайнято (попередньо)",
     "Busy" : "Зайнято",
     "Out of office" : "Поза межами офісу",
     "Unknown" : "Невідомо",
-    "{name} accepted your invitation." : "{name} прийняв ваше запрошення.",
-    "{name} accepted {organizerName}'s invitation." : "{name} прийняв запрошення від {organizerName}.",
-    "{name} declined your invitation." : "{name} відхилив ваше запрошення.",
-    "{name} declined {organizerName}'s invitation." : "{name} відхилив запрошення від {organizerName}.",
-    "{name} has delegated their invitation." : "{name} делегував своє запрошення.",
-    "{name} marked their participation as tentative." : "{name} позначив свою участь як попередню.",
-    "{name} did not respond to your invitation yet." : "{name} поки не відповів на ваше запрошення.",
-    "{name} did not respond to {organizerName}'s invitation yet." : "{name} поки не відповів на запрошення від {organizerName}.",
     "Create Talk room for this event" : "Створити Кімнату переговорів для цієї події",
     "Show busy times" : "Показати зайнятий час",
     "Successfully appended link to talk room to description." : "Успішно додано посилання на Кімнату переговорів до опису події.",
     "Error creating Talk room" : "Помилка при створенні Кімнати переговорів",
-    "Send e-mail" : "Надіслати електронну пошту",
     "Chairperson" : "Голова зборів",
     "Required participant" : "Обов'язковий учасник",
     "Optional participant" : "Необов'язковий учасник",
     "Non-participant" : "Не-учасник",
     "Remove attendee" : "Вилучити учасника",
-    "Search for e-mails, users, contacts, resources or rooms" : "Пошук адрес електронної пошти, користувачів, контактів, ресурсів і кімнат",
     "No match found" : "Жодного не знайдено",
     "No attendees yet" : "Поки жодного учасника",
     "(organizer)" : "(організатор)",
     "Remove color" : "Вилучити колір",
     "Event title" : "Назва події",
     "All day" : "Цілий день",
-    "Can not modify all-day setting for events that are part of a recurrence-set." : "Неможливо змінити налаштування зайнятості цилого дня для подій, що повторюються.",
     "from {startDate}" : "з {startDate}",
     "from {startDate} at {startTime}" : "до {startDate} о {startTime}",
     "to {endDate}" : "до {endDate}",
@@ -175,7 +165,6 @@ OC.L10N.register(
     "on date" : "у дату",
     "after" : "після",
     "_time_::_times_" : ["раз","разів","разів","рази"],
-    "This event is the recurrence-exception of a recurrence-set. You can not add a recurrence-rule to it." : "Ця подія є винятком з повторюваного набору. Ви не можете додати правила повтору для неї.",
     "first" : "перший",
     "third" : "третій",
     "fourth" : "четвертий",
@@ -269,11 +258,8 @@ OC.L10N.register(
     "in {monthNames} on the {ordinalNumber} {byDaySet}" : "у {monthNames} у {ordinalNumber} {byDaySet}",
     "until {untilDate}" : "до {untilDate}",
     "_%n time_::_%n times_" : ["%n раз","%n разів","%n разів","%n рази"],
-    "Untitled event" : "Подія без назви",
     "Untitled task" : "Завдання без назви",
     "Please ask your administrator to enable the Tasks App." : "Зверніться до вашого адміністратора щодо увімкнення застосунку Завдання",
-    "next year" : "наступного року",
-    "today" : "сьогодні",
     "_+%n more_::_+%n more_" : ["+%n раз ще","+%n разів ще","+%n разів ще","+%n рази ще"],
     "When shared show" : "Показувати при поширенні",
     "When shared show full event" : "При поширенні показувати подію повністю",
@@ -291,7 +277,6 @@ OC.L10N.register(
     "Confirmation about the overall status of the event." : "Підтвердження загального статусу події.",
     "Show as" : "Показати як",
     "Take this event into account when calculating free-busy information." : "Брати до уваги цю подію при розрахунку інформації про вильний/зайнятий час.",
-    "Free" : "Вільно",
     "Categories" : "Категорії",
     "Categories help you to structure and organize your events." : "Категорії допомагають структурувати і впорядковувати ваші події.",
     "Search or add categories" : "Знайти або додати категорії",
@@ -319,14 +304,10 @@ OC.L10N.register(
     "Review" : "На перегляд",
     "Office" : "Офіс",
     "Contributor week" : "Тиждень постачальника",
-    "Party" : "Вечірка",
-    "Celebration" : "Святкування",
     "Mail" : "Пошта",
     "Soccer" : "Футбол",
     "Football" : "Американський футбол",
     "Gaming" : "Ігри",
-    "Play" : "Грати",
-    "Game" : "Гра",
     "Drive" : "Їхати автомобілем",
     "Bicycle" : "Їхати велосипедом",
     "Cycle" : "Їхати колесами",
@@ -380,6 +361,8 @@ OC.L10N.register(
     "Lecture" : "Лекція",
     "Seminar" : "Семінар",
     "Photograph" : "Фотограф",
+    "Party" : "Вечірка",
+    "Celebration" : "Святкування",
     "Celebrate" : "Святкування",
     "Shopping" : "Шопінг",
     "Skate" : "Ковзани",
